==> mastapy-14.0.0rc3-py3-none-any.whl: mastapy/_private/_internal/implicit/enum_with_selected_value/destination_design_state.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.system_model.analyses_and_results.static_loads.duty_cycle_definition import (
    _7141,
)
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import List, Type, Any, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_DestinationDesignState")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_DestinationDesignState",)


class EnumWithSelectedValue_DestinationDesignState(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_DestinationDesignState

    A specific implementation of 'EnumWithSelectedValue' for 'DestinationDesignState' types.
    """

    __qualname__ = "DestinationDesignState"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_DestinationDesignState]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_DestinationDesignState]",
    ) -> "_7141.DestinationDesignState":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _7141.DestinationDesignState
        """
        return _7141.DestinationDesignState

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_DestinationDesignState]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _7141.DestinationDesignState.type_()

    @property
    def selected_value(self: "Self") -> "_7141.DestinationDesignState":
        """mastapy.system_model.analyses_and_results.static_loads.duty_cycle_definition.DestinationDesignState

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_7141.DestinationDesignState]":
        """List[mastapy.system_model.analyses_and_results.static_loads.duty_cycle_definition.DestinationDesignState]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.0.1b1-py3-none-any.whl: mastapy/_private/_internal/implicit/enum_with_selected_value/destination_design_state.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.system_model.analyses_and_results.static_loads.duty_cycle_definition import (
    _7143,
)

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_DestinationDesignState")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_DestinationDesignState",)


class EnumWithSelectedValue_DestinationDesignState(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_DestinationDesignState

    A specific implementation of 'EnumWithSelectedValue' for 'DestinationDesignState' types.
    """

    __qualname__ = "DestinationDesignState"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_DestinationDesignState]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_DestinationDesignState]",
    ) -> "_7143.DestinationDesignState":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _7143.DestinationDesignState
        """
        return _7143.DestinationDesignState

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_DestinationDesignState]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _7143.DestinationDesignState.type_()

    @property
    def selected_value(self: "Self") -> "_7143.DestinationDesignState":
        """mastapy.system_model.analyses_and_results.static_loads.duty_cycle_definition.DestinationDesignState

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_7143.DestinationDesignState]":
        """List[mastapy.system_model.analyses_and_results.static_loads.duty_cycle_definition.DestinationDesignState]

        Note:
            This property is readonly.
        """
        return None
